/*****************************************************************************
*								18f4520_Flash.h								 *
******************************************************************************

Implements bulk read, write, and erase operations to the flash program memory
on the PIC18F4520.

*****************************************************************************/

#ifndef __18F4520_FLASH_H
#define __18F4520_FLASH_H

#include <string.h>


/*****************************************************************************
						PUBLIC TYPES, MACROS, DEFINITIONS
*****************************************************************************/

/* Sizes of read and erase blocks, to make sure the flash address pointers
 * passed to WriteFlash and EraseFlash are on boundaries. */
#define WRITE_LENGTH	32		//# of bytes that must be written at once
#define ERASE_LENGTH	64		//# of bytes that must be erased at once


/* Reading is handled byte by byte and we can simply use the built in memcpy.
 * Note that the arguments are flipped in this macro definition; that is
 * because our read/write/erase all have flash address as first arg, while the
 * built in functions have destination as first argument.
 *
 * Argument types:
 * near unsigned short long addr,
 * unsigned char *buff,
 * unsigned int bytes
 */
#define ReadFlash(addr, buff, bytes)	memcpypgm2ram(buff, addr, bytes);

/*****************************************************************************
							PUBLIC FUNCTION PROTOTYPES
*****************************************************************************/

/* Writes 'bytes' number of bytes from the data source to the flash starting
 * in the write block containing 'addr'.  If the block of memory to be written
 * is not completely within the flash data section (as defined in 18fUtil.h),
 * nothing is written and an appropriate error code is returned.  'dest' must
 * point to the start of a write block, otherwise it will be shifted to the
 * closest boundary lower in memory. */
unsigned char WriteFlash(near unsigned short long dest, unsigned char *src, unsigned int bytes);

/* Erases 'bytes' number of bytes from the flash starting at the erase block
 * containing 'addr'.  If the block of memory to erase is not completely
 * within the flash data section (as defined in 18fUtil.h), nothing is erased
 * and an appropriate error code is returned.  'addr' must point to the start
 * of an erase block, otherwise it will be shifted to the closest boundary
 * lower in memory. */
unsigned char EraseFlash(near unsigned short long addr, unsigned int bytes);

//This is a simple function that only reads one byte at a time.
unsigned char ReadFlashByte(near unsigned short long addr);

//This is function reads two bytes at a time
unsigned int ReadFlashTwoBytes(near unsigned short long addr);


#endif //__18F4520_FLASH_H
