/*****************************************************************************
*                              18fSensors.h                                  *
******************************************************************************

Implements communication between the Controller board and the Sensor boards
via I2C protocol and allows access to the sensor readings, both raw and
converted to force values.

*****************************************************************************/

#ifndef __18FSENSORS_H
#define __18FSENSORS_H

#include "18fUtil.h"
#include "ControllerMath.h"
#include "PhysicalConfig.h"


/*****************************************************************************
*					PUBLIC TYPES, MACROS, DEFINITIONS                        *
*****************************************************************************/

/* Target baud rate in KBps */
#define I2C_BAUD		100

/* Value used to set that baud rate (as close as possible).  See Errata for
 * new formula.
 * I2C_NUMBR = (FOSC/4)/I2C_BAUD - (FOSC/4)/(1111) - 1
 */
#define I2C_NUMBR		0x59


/*****************************************************************************
							PUBLIC VARIABLES
*****************************************************************************/


/*****************************************************************************
						PUBLIC FUNCTION PROTOTYPES
*****************************************************************************/

/* Initializes the I2C in master mode and initializes the sensor readings. */
void SNS_InitSensors(void);

/* Resets the I2C module, in master mode */
void SNS_ResetI2C(void);

/* Polls all the sensors and saves both the raw and force values. */
void SNS_PollSensors(void);

void SNS_ZeroSensors(void);

/* Gets an single sensor's raw reading */
unsigned char SNS_GetSingleRaw(Leg_t leg, SensorType_t type);

/* Gets an single sensor's force reading */
Number_t SNS_GetSingleForce(Leg_t leg, SensorType_t type);

/* Copies the raw readings from all sensors of a given type into the target
 * SensorGroupRaw_t object.
 */
void SNS_GetTypeRaw(SensorType_t type, SensorGroupRaw_t *dest);

/* Copies the force readings from all sensors of a given type into the target
 * SensorGroupNumber_t object.
 */
void SNS_GetTypeForce(SensorType_t type, SensorGroupNumber_t *dest);

/* Copies all raw sensor readings into the target SensorRaw_t */
void SNS_GetAllRaw(SensorRaw_t *dest);

/* Copies all force readings into the target SensorNumber_t */
void SNS_GetAllForce(SensorNumber_t *dest);

#endif //__18FSENSOR_H
