#include "CtrlOpenLoop.h"
#include "ControllerMath.h"
#include "PhysicalConfig.h"
#include "servo.h"
#include "FileReader.h"
#include "18f4520_flash.h"

static void take_step(void);

static unsigned char ctrl_init = 0;
static unsigned char ctrl_enable = 0;
static unsigned int gait_location;
static unsigned int current_inx;
static unsigned int max_inx;
static ServoNumber_t current_servos;

void CTRL_OL_EnableCtrl(void)
{
	if (ctrl_init)
		ctrl_enable = 1;
}

void CTRL_OL_DisableCtrl(void)
{
	ctrl_enable = 0;
}

void CTRL_OL_ResetCtrl(void)
{
	//Find the gait's location in memory
	gait_location = FR_FindEntry(OPEN_LOOP_GAIT_FILE_ENTRY);

	//Check to make sure the gait was found
	if (gait_location != NULL_MEM_PTR)
	{
		//Read the size of the gait
		max_inx = ReadFlashTwoBytes(gait_location);

		//Advance the address by two bytes over the size of the gait
		gait_location += 2;
		
		//Make sure the gait isn't empty
		if (max_inx != 0)
		{
			//Initialize the gait
			current_inx = 0;
			
			//Take the first step
			take_step();
			
			//Set the initialization flag
			ctrl_init = 1;
		}
	}
	else
		//Indicate file error
		DSP_SetError(0x22);
}
	

void Ctrl_OpenLoop(void)
{
	//Check to make the gait is initialized and enabled
	if (ctrl_init)
	{
		if (ctrl_enable)
		{
			//Execute the loop
			take_step();
		}
		else
		{
			SRV_SetAllAbs(&current_servos);
			SRV_SetAllRel(SRV_GetOffset());
			SRV_UpdateServoValues();
		}
	}
	else
	{
		SRV_SetAllAbs(SRV_GetOffset());
		SRV_UpdateServoValues();
	}
}

unsigned int Ctrl_OL_GetIndex(void)
{
	if (ctrl_init && ctrl_enable)
		return current_inx;
	else
		return 0xFFFF;
}

static void take_step(void)
{
	static ServoType_t type;
	static Leg_t leg;
	static Number_t pos = 0;
	static unsigned int offset;

	//Calculate the current position in the gait memory
	offset = gait_location + (NUM_SERVOS * current_inx);
	
	//Loop through each servo and read it's position from memory
	for(type = 0; type < NUM_SERVO_TYPES; type++)
		for(leg = 0; leg < NUM_LEGS; leg++)
		{
			//Since the entire gait is precalculated we don't
			//need to worry about fractional bits
			pos.whole = ReadFlashByte(offset);
			
			//Update the sevo
			SRV_SetSingleAbs(leg, type, pos);
			
			//Advance one byte in memory
			offset++;
		}
	
	//Save position in memory
	SRV_GetAllTargets(&current_servos);
	
	//Add servo offset
	SRV_SetAllRel(SRV_GetOffset());
	
	//Send the updated values to the servos
	SRV_UpdateServoValues();

	//Advance one entry in memory
	current_inx++;
	//If the gait ended, loop back to the start
	if (current_inx >= max_inx)
		current_inx = 0;
}
