/*****************************************************************************
 *                                 Display.h                                 *
 *****************************************************************************

Display routines for the StickyBot controller board.

*****************************************************************************/

#ifndef __DISPLAY_H
#define __DISPLAY_H

#include "18fUtil.h"
#include <p18cxxx.h>


/*****************************************************************************
						PUBLIC TYPES, MACROS, DEFINITIONS
*****************************************************************************/
#define	G_LED				(PORTCbits.RC0)
#define	R_LED				(PORTCbits.RC1)

#define DSP_SetGreen(status)	(G_LED = status)
#define DSP_SetRed(status)		(R_LED = status)

#define DSP_ToggleGreen() 		(G_LED = !G_LED)
#define DSP_ToggleRed()			(R_LED = !R_LED)


/*****************************************************************************
						PUBLIC FUNCTION PROTOYPES
*****************************************************************************/

/* Initializes the display (ports, pins etc) */
void DSP_InitDisplay(void);

/* Indicates to the user that everything has initialized correctly */
void DSP_Hello(void);

/* Sets the error code which is displayed by calls to DSP_DisplayError.  The
 * upper nibble indicates which module generated the error, and the lower
 * nibble indicates a particular error in that module (listed in 18fUtils.h).
 */
unsigned char DSP_SetError(unsigned char err);

/* Handles the actual display of error codes set by DSP_SetError. */
void DSP_DisplayError(void);

/* Sets the heartbeat timing "postscalar". The heartbeat will toggle every
 * 2^(hb_bit+1) calls to DSP_Heartbeat.
 */
void DSP_SetHeartbeat(unsigned char hb_bit);

/* Handles the actual display of the heartbeat. */
void DSP_Heartbeat(void);

#endif /* __DISPLAY_H */
