/*****************************************************************************
 *                                   Keys.h                                  *
 *****************************************************************************
 
Key press routines for StickyBot Controller board (specifically for PIC18Fxxx)
Assumes that the keys are normally high (pulled-up in hardware).

*****************************************************************************/

#ifndef __KEYS_H
#define __KEYS_H

#include "18fUtil.h"


/*****************************************************************************
						PUBLIC TYPES, MACROS, DEFINITIONS
*****************************************************************************/

/* Key events, including those for events on the remote keys */
typedef enum {
	NO_EVENT = 0,
	B0_PRESS,
	B1_PRESS,
	B0_HOLD,
	B1_HOLD,
	B0_B1_HOLD,
	R0_PRESS,
	R1_PRESS,
	R2_PRESS,
	R3_PRESS,
	R0_HOLD,
	R1_HOLD,
	R2_HOLD,
	R3_HOLD,
	R0_R1_HOLD,
	R2_R3_HOLD
} KeyEvent_t;


/*****************************************************************************
						PUBLIC FUNCTION PROTOTYPES
*****************************************************************************/

/* Initializes all Key pins */
void InitKeys(void);

/* Checks what key events have happened since the last call to CheckKeyEvent */
KeyEvent_t CheckKeyEvent(void);


/* Checks the value on the 4pin DIP switch on the remote and returns it in the
 * lower nibble.
 */
unsigned char CheckRemoteDIPSwitch(void);


#endif
