/*
	ServoConfig.h
	
	Header file containing setup for servo controller
	
	Jonathan Karpick
	7 May 2006
	
*/

#ifndef _SERVOCONFIG_H_
#define _SERVOCONFIG_H_

#include "PhysicalConfig.h"

	#define NUM_OF_SERV_P1	8		
	#define PORT_SERV_P1	PORTD
	#define TRIS_SERV_P1	TRISD
	
	#define NUM_OF_SERV_P2	4	
	#define PORT_SERV_P2	PORTB
	#define TRIS_SERV_P2	TRISB
	
	#define NUM_OF_SERV_P3	0
	#define PORT_SERV_P3	PORTC
	#define TRIS_SERV_P3	TRISC
	
	#define NUM_OF_SERV	(NUM_OF_SERV_P1 + NUM_OF_SERV_P2 + NUM_OF_SERV_P3)	// TOT NUM OF SERVOS

	#if NUM_OF_SERV == 0
		#error "No servos present"
	#endif
	
	#if (NUM_OF_SERV != (NUM_LEGS * NUM_SERVO_TYPES))
		#error "Servo configuration mismatch: number of servos not constant"
	#endif
	
	#if (NUM_OF_SERV_P1 > 0)
		#define NUM_SERVO_PORT_1 1
	#else
		#define NUM_SERVO_PORT_1 0
	#endif

	#if (NUM_OF_SERV_P2 > 0)
		#define NUM_SERVO_PORT_2 1
	#else
		#define NUM_SERVO_PORT_2 0
	#endif
	
	#if (NUM_OF_SERV_P3 > 0)
		#define NUM_SERVO_PORT_3 1
	#else
		#define NUM_SERVO_PORT_3 0
	#endif
	
	#define NUM_SERVOPORT (NUM_SERVO_PORT_1 + NUM_SERVO_PORT_2 + NUM_SERVO_PORT_3)
	#undef NUM_SERVO_PORT_1
	#undef NUM_SERVO_PORT_2
	#undef NUM_SERVO_PORT_3
	
	#if (NUM_OF_SERV_P1 == 1)
		#define MASK_SERV_P1 0b00000001
	#elif (NUM_OF_SERV_P1 == 2)
		#define MASK_SERV_P1 0b00000011
	#elif (NUM_OF_SERV_P1 == 3)
		#define MASK_SERV_P1 0b00000111
	#elif (NUM_OF_SERV_P1 == 4)
		#define MASK_SERV_P1 0b00001111
	#elif (NUM_OF_SERV_P1 == 5)
		#define MASK_SERV_P1 0b00011111
	#elif (NUM_OF_SERV_P1 == 6)
		#define MASK_SERV_P1 0b00111111
	#elif (NUM_OF_SERV_P1 == 7)
		#define MASK_SERV_P1 0b01111111
	#elif (NUM_OF_SERV_P1 == 8)
		#define MASK_SERV_P1 0b11111111
	#elif (NUM_OF_SERV_P1 > 8)
		#error "Too many servos on first port!"
	#endif
	
	#if (NUM_OF_SERV_P2 == 1)
		#define MASK_SERV_P2 0b00000001
	#elif (NUM_OF_SERV_P2 == 2)
		#define MASK_SERV_P2 0b00000011
	#elif (NUM_OF_SERV_P2 == 3)
		#define MASK_SERV_P2 0b00000111
	#elif (NUM_OF_SERV_P2 == 4)
		#define MASK_SERV_P2 0b00001111
	#elif (NUM_OF_SERV_P2 == 5)
		#define MASK_SERV_P2 0b00011111
	#elif (NUM_OF_SERV_P2 == 6)
		#define MASK_SERV_P2 0b00111111
	#elif (NUM_OF_SERV_P2 == 7)
		#define MASK_SERV_P2 0b01111111
	#elif (NUM_OF_SERV_P2 == 8)
		#define MASK_SERV_P2 0b11111111
	#elif (NUM_OF_SERV_P2 > 8)
		#error "Too many servos on second port!"
	#endif
	
	
	#if (NUM_OF_SERV_P3 == 1)
		#define MASK_SERV_P3 0b00000001
	#elif (NUM_OF_SERV_P3 == 2)
		#define MASK_SERV_P3 0b00000011
	#elif (NUM_OF_SERV_P3 == 3)
		#define MASK_SERV_P3 0b00000111
	#elif (NUM_OF_SERV_P3 == 4)
		#define MASK_SERV_P3 0b00001111
	#elif (NUM_OF_SERV_P3 == 5)
		#define MASK_SERV_P3 0b00011111
	#elif (NUM_OF_SERV_P3 == 6)
		#define MASK_SERV_P3 0b00111111
	#elif (NUM_OF_SERV_P3 == 7)
		#define MASK_SERV_P3 0b01111111
	#elif (NUM_OF_SERV_P3 == 8)
		#define MASK_SERV_P3 0b11111111
	#elif (NUM_OF_SERV_P3 > 8)
		#error "Too many servos on third port!"
	#endif

#endif 
