#include "18fUtil.h"
#include "CtrlCloseLoop.h"
#include "CtrlOpenLoop.h"
#include "StanceController.h"
#include "SBConfig.h"

/*** FLASH DATA FILE ***

This file defines the initial gait parameters. This file is included
such that every upload of code comes with a gait.

************************/

#define FlashVariableAddress(var) (((unsigned int)&var) - FLASH_DATA)
#define FlashPointerAddress(var) (((unsigned int)var) - FLASH_DATA)

#pragma romdata FlashData = FLASH_DATA
const rom unsigned int SizeOfFlashFile;

const rom unsigned char ServoTableEntry = 0x30;
const rom unsigned int ServoTableAddress; 

const rom unsigned char SensorTableEntry = 0x31;
const rom unsigned int SensorTableAddress; 

const rom unsigned char FourFootStanceControllerEntry = FOUR_FOOT_STANCE_CTRL;
const rom unsigned int FourFootStanceControllerAddress;

const rom unsigned char ForwardSlashStanceControllerEntry = FRW_SLSH_STANCE_CTRL;
const rom unsigned int ForwardSlashStanceControllerAddress;

const rom unsigned char BackwardSlashStanceControllerEntry = BCK_SLSH_STANCE_CTRL;
const rom unsigned int BackwardSlashStanceControllerAddress;

const rom unsigned char OpenLoopGaitEntry = OPEN_LOOP_GAIT_FILE_ENTRY;
const rom unsigned int OpenLoopGaitAddress;

const rom unsigned char CloseLoopGaitEntry = CLOSE_LOOP_GAIT_FILE_ENTRY;
const rom unsigned int CloseLoopGaitAddress;

/* Must be last in TOC! */
const rom unsigned char EndOfHeader = HEADER_END;

/* Servo Table */
#ifdef VER_STICKYBOT
	const rom unsigned char ServoConfig[] = {	
		0x0C, //12 servos
		
		0x36, 0xc1, 0x31, 0xb2, 0x74, 0x91, 0x99, 0x89, 0x7f, 0x67, 0x8b, 0x84, 
		//0x3a, 0xcb, 0x46, 0xb2, 0x6e, 0x91, 0x99, 0x8e, 0x7f, 0x67, 0x8b, 0x84, 
	
		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 
		  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0
	   //195,  221, 209, 217, 208, 222, 215, 242, 255, 151, 174, 255, //Upper
	   //31,  76,   51,  61,  48,  66,  39,  62, 103,   0,  12, 100  //Lower
	};
#endif
#ifdef VER_STICKYBOT2
	const rom unsigned char ServoConfig[] = {	
		0x0C, //12 servos
		0xb7, 0x34, 0xce, 0x50, 0x5e, 0xab, 0x93, 0x75, 0x6e, 0x61, 0x6e, 0x65, //Home
		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 	//Upper
		0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0		//Lower
	};
#endif


extern const rom unsigned int ServoTableAddress =
	FlashPointerAddress(ServoConfig); 

/* Sensor Table */
const rom unsigned char SensorTable[] = {
	0x04, //4 sensors
	120, 120, 120, 120, //Zeros
//	0x33, 0x00, 0x33, 0x00, 0x33, 0x00, 0x33, 0x00 //Slopes
	0x83, 0x00, 0x60, 0x00, 0x7D, 0x00, 0xB7, 0x00 //Slopes

};
extern const rom unsigned int SensorTableAddress =
	FlashPointerAddress(SensorTable);

/* Stance controller */
const rom unsigned char FourFootStanceController[] = {
	//G
	0x80, 0x00, 0x80, 0x00, 0x80, 0x00, 0x80, 0x00,
	0x80, 0x00, 0x80, 0xFF, 0x80, 0x00, 0x80, 0xFF,
	0x80, 0x00, 0x80, 0x00, 0x80, 0xFF, 0x80, 0xFF,
	0x80, 0x00, 0x80, 0xFF, 0x80, 0xFF, 0x80, 0x00,
	//inv(G)
	0x80, 0x00, 0x80, 0x00, 0x80, 0x00, 0x80, 0x00,
	0x80, 0x00, 0x80, 0xFF, 0x80, 0x00, 0x80, 0xFF,
	0x80, 0x00, 0x80, 0x00, 0x80, 0xFF, 0x80, 0xFF,
	0x80, 0x00, 0x80, 0xFF, 0x80, 0xFF, 0x80, 0x00,
	//Kg
	0x00, 0x00, 0x00, 0x04, 0x00, 0x04, 0x00, 0x04
};
extern const rom unsigned int FourFootStanceControllerAddress =
	FlashPointerAddress(FourFootStanceController);

const rom unsigned char ForwardSlashStanceController[] = {
	//G
	0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0xB5, 0x00, 0xB5, 0x00, 0x00, 0x00,
	0x00, 0x00, 0xB5, 0x00, 0x4B, 0xFF, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01,
	//inv(G)
	0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0xB5, 0x00, 0xB5, 0x00, 0x00, 0x00,
	0x00, 0x00, 0xB5, 0x00, 0x4B, 0xFF, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01,
	//Kg
	0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00
};
extern const rom unsigned int ForwardSlashStanceControllerAddress =
	FlashPointerAddress(ForwardSlashStanceController);

const rom unsigned char BackwardSlashStanceController[] = {
	//G
	0xB5, 0x00, 0x00, 0x00, 0x00, 0x00, 0xB5, 0x00,
	0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 
	0xB5, 0x00, 0x00, 0x00, 0x00, 0x00, 0x4B, 0xFF,
	//inv(G)
	0xB5, 0x00, 0x00, 0x00, 0x00, 0x00, 0xB5, 0x00,
	0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 
	0xB5, 0x00, 0x00, 0x00, 0x00, 0x00, 0x4B, 0xFF,
	//Kg
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04
};
extern const rom unsigned int BackwardSlashStanceControllerAddress =
	FlashPointerAddress(BackwardSlashStanceController);

#ifdef VER_STICKYBOT
#include SB1_RCFILE
#endif

#ifdef VER_STICKYBOT2
#include SB2_RCFILE
#endif
/*
const rom unsigned char OpenLoopGait[] = {
	0xC8, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x20, 0xE2, 0xE2, 0x20, 0x00, 0x00, 0x00, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1F, 0xE2, 0xE2, 0x1F, 0xFD, 0x00, 0x00, 0xFD, 
	0x50, 0x00, 0x00, 0x50, 0x1F, 0xE2, 0xE2, 0x1F, 0xFA, 0x00, 0x00, 0xFA, 
	0x50, 0x00, 0x00, 0x50, 0x1E, 0xE2, 0xE2, 0x1E, 0xF7, 0x00, 0x00, 0xF7, 
	0x50, 0x00, 0x00, 0x50, 0x1D, 0xE2, 0xE2, 0x1D, 0xF4, 0x00, 0x00, 0xF4, 
	0x50, 0x00, 0x00, 0x50, 0x1D, 0xE2, 0xE2, 0x1D, 0xF1, 0x00, 0x00, 0xF1, 
	0x50, 0x00, 0x00, 0x50, 0x1C, 0xE2, 0xE2, 0x1C, 0xEE, 0x00, 0x00, 0xEE, 
	0x50, 0x00, 0x00, 0x50, 0x1B, 0xE2, 0xE2, 0x1B, 0xEB, 0x00, 0x00, 0xEB, 
	0x50, 0x00, 0x00, 0x50, 0x1A, 0xE2, 0xE2, 0x1A, 0xE8, 0x00, 0x00, 0xE8, 
	0x50, 0x00, 0x00, 0x50, 0x1A, 0xE2, 0xE2, 0x1A, 0xE5, 0x00, 0x00, 0xE5, 
	0x50, 0x00, 0x00, 0x50, 0x19, 0xE2, 0xE2, 0x19, 0xE2, 0x00, 0x00, 0xE2, 
	0x48, 0x00, 0x00, 0x48, 0x18, 0xE2, 0xE2, 0x18, 0xE2, 0x00, 0x00, 0xE2, 
	0x40, 0x00, 0x00, 0x40, 0x18, 0xE2, 0xE2, 0x18, 0xE2, 0x00, 0x00, 0xE2, 
	0x38, 0x00, 0x00, 0x38, 0x17, 0xE2, 0xE2, 0x17, 0xE2, 0x00, 0x00, 0xE2, 
	0x30, 0x00, 0x00, 0x30, 0x16, 0xE2, 0xE2, 0x16, 0xE2, 0x00, 0x00, 0xE2, 
	0x28, 0x00, 0x00, 0x28, 0x16, 0xE2, 0xE2, 0x16, 0xE2, 0x00, 0x00, 0xE2, 
	0x20, 0x00, 0x00, 0x20, 0x15, 0xE2, 0xE2, 0x15, 0xE2, 0x00, 0x00, 0xE2, 
	0x18, 0x00, 0x00, 0x18, 0x14, 0xE2, 0xE2, 0x14, 0xE2, 0x00, 0x00, 0xE2, 
	0x10, 0x00, 0x00, 0x10, 0x13, 0xE2, 0xE2, 0x13, 0xE2, 0x00, 0x00, 0xE2, 
	0x08, 0x00, 0x00, 0x08, 0x13, 0xE2, 0xE2, 0x13, 0xE2, 0x00, 0x00, 0xE2, 
	0x00, 0x00, 0x00, 0x00, 0x12, 0xE2, 0xE2, 0x12, 0xE2, 0x00, 0x00, 0xE2, 
	0x00, 0x00, 0x00, 0x00, 0x11, 0xE2, 0xE2, 0x11, 0xE2, 0x00, 0x00, 0xE2, 
	0x00, 0x00, 0x00, 0x00, 0x11, 0xE2, 0xE2, 0x11, 0xE2, 0x00, 0x00, 0xE2, 
	0x00, 0x00, 0x00, 0x00, 0x10, 0xE2, 0xE2, 0x10, 0xE2, 0x00, 0x00, 0xE2, 
	0x00, 0x00, 0x00, 0x00, 0x0F, 0xE2, 0xE2, 0x0F, 0xE2, 0x00, 0x00, 0xE2, 
	0x00, 0x00, 0x00, 0x00, 0x0E, 0xE2, 0xE2, 0x0E, 0xE3, 0x00, 0x00, 0xE3, 
	0x00, 0x00, 0x00, 0x00, 0x0E, 0xE2, 0xE2, 0x0E, 0xE5, 0x00, 0x00, 0xE5, 
	0x00, 0x00, 0x00, 0x00, 0x0D, 0xE2, 0xE2, 0x0D, 0xE7, 0x00, 0x00, 0xE7, 
	0x00, 0x00, 0x00, 0x00, 0x0C, 0xE2, 0xE2, 0x0C, 0xE8, 0x00, 0x00, 0xE8, 
	0x00, 0x00, 0x00, 0x00, 0x0C, 0xE2, 0xE2, 0x0C, 0xE9, 0x00, 0x00, 0xE9, 
	0x00, 0x00, 0x00, 0x00, 0x0B, 0xE2, 0xE2, 0x0B, 0xEB, 0x00, 0x00, 0xEB, 
	0x00, 0x00, 0x00, 0x00, 0x0A, 0xE2, 0xE2, 0x0A, 0xEC, 0x00, 0x00, 0xEC, 
	0x00, 0x00, 0x00, 0x00, 0x0A, 0xE2, 0xE2, 0x0A, 0xEE, 0x00, 0x00, 0xEE, 
	0x00, 0x00, 0x00, 0x00, 0x09, 0xE2, 0xE2, 0x09, 0xF0, 0x00, 0x00, 0xF0, 
	0x00, 0x00, 0x00, 0x00, 0x08, 0xE2, 0xE2, 0x08, 0xF1, 0x00, 0x00, 0xF1, 
	0x00, 0x00, 0x00, 0x00, 0x08, 0xE2, 0xE2, 0x08, 0xF2, 0x00, 0x00, 0xF2, 
	0x00, 0x00, 0x00, 0x00, 0x07, 0xE2, 0xE2, 0x07, 0xF4, 0x00, 0x00, 0xF4, 
	0x00, 0x00, 0x00, 0x00, 0x07, 0xE2, 0xE2, 0x07, 0xF5, 0x00, 0x00, 0xF5, 
	0x00, 0x00, 0x00, 0x00, 0x06, 0xE2, 0xE2, 0x06, 0xF7, 0x00, 0x00, 0xF7, 
	0x00, 0x00, 0x00, 0x00, 0x05, 0xE2, 0xE2, 0x05, 0xF9, 0x00, 0x00, 0xF9, 
	0x00, 0x00, 0x00, 0x00, 0x05, 0xE2, 0xE2, 0x05, 0xFA, 0x00, 0x00, 0xFA, 
	0x00, 0x00, 0x00, 0x00, 0x04, 0xE2, 0xE2, 0x04, 0xFB, 0x00, 0x00, 0xFB, 
	0x00, 0x00, 0x00, 0x00, 0x03, 0xE2, 0xE2, 0x03, 0xFD, 0x00, 0x00, 0xFD, 
	0x00, 0x00, 0x00, 0x00, 0x03, 0xE2, 0xE2, 0x03, 0xFE, 0x00, 0x00, 0xFE, 
	0x00, 0x00, 0x00, 0x00, 0x02, 0xE2, 0xE2, 0x02, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x01, 0xE2, 0xE2, 0x01, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0xE2, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0xE2, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xFF, 0xE2, 0xE2, 0xFF, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xFE, 0xE2, 0xE2, 0xFE, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xFE, 0xE2, 0xE2, 0xFE, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xFD, 0xE2, 0xE2, 0xFD, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xFC, 0xE2, 0xE2, 0xFC, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x0A, 0x0A, 0x00, 0xFB, 0xE2, 0xE2, 0xFB, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x14, 0x14, 0x00, 0xFB, 0xE2, 0xE2, 0xFB, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x1E, 0x1E, 0x00, 0xFA, 0xE2, 0xE2, 0xFA, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x28, 0x28, 0x00, 0xF9, 0xE2, 0xE2, 0xF9, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x32, 0x32, 0x00, 0xF9, 0xE2, 0xE2, 0xF9, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x3C, 0x3C, 0x00, 0xF8, 0xE2, 0xE2, 0xF8, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x46, 0x46, 0x00, 0xF8, 0xE2, 0xE2, 0xF8, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xF7, 0xE2, 0xE2, 0xF7, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xF6, 0xE4, 0xE4, 0xF6, 0x00, 0x02, 0x02, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xF6, 0xE5, 0xE5, 0xF6, 0x00, 0x05, 0x05, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xF5, 0xE7, 0xE7, 0xF5, 0x00, 0x07, 0x07, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xF4, 0xE8, 0xE8, 0xF4, 0x00, 0x0A, 0x0A, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xF3, 0xEA, 0xEA, 0xF3, 0x00, 0x0C, 0x0C, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xF3, 0xEB, 0xEB, 0xF3, 0x00, 0x0F, 0x0F, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xF2, 0xED, 0xED, 0xF2, 0x00, 0x12, 0x12, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xF1, 0xEE, 0xEE, 0xF1, 0x00, 0x14, 0x14, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xF1, 0xF0, 0xF0, 0xF1, 0x00, 0x16, 0x16, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xF0, 0xF2, 0xF2, 0xF0, 0x00, 0x19, 0x19, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xEF, 0xF3, 0xF3, 0xEF, 0x00, 0x1C, 0x1C, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xEF, 0xF5, 0xF5, 0xEF, 0x00, 0x1E, 0x1E, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xEE, 0xF6, 0xF6, 0xEE, 0x00, 0x21, 0x21, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xED, 0xF8, 0xF8, 0xED, 0x00, 0x23, 0x23, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xEC, 0xF9, 0xF9, 0xEC, 0x00, 0x26, 0x26, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xEC, 0xFB, 0xFB, 0xEC, 0x00, 0x28, 0x28, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xEB, 0xFC, 0xFC, 0xEB, 0x00, 0x2B, 0x2B, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xEA, 0xFE, 0xFE, 0xEA, 0x00, 0x2D, 0x2D, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xEA, 0xFF, 0xFF, 0xEA, 0x00, 0x30, 0x30, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE9, 0x01, 0x01, 0xE9, 0x00, 0x32, 0x32, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE8, 0x03, 0x03, 0xE8, 0x00, 0x2F, 0x2F, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE8, 0x04, 0x04, 0xE8, 0x00, 0x2D, 0x2D, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE7, 0x06, 0x06, 0xE7, 0x00, 0x2A, 0x2A, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE6, 0x07, 0x07, 0xE6, 0x00, 0x28, 0x28, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE5, 0x09, 0x09, 0xE5, 0x00, 0x25, 0x25, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE5, 0x0A, 0x0A, 0xE5, 0x00, 0x23, 0x23, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE4, 0x0C, 0x0C, 0xE4, 0x00, 0x20, 0x20, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE3, 0x0D, 0x0D, 0xE3, 0x00, 0x1E, 0x1E, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE3, 0x0F, 0x0F, 0xE3, 0x00, 0x1B, 0x1B, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x10, 0x10, 0xE2, 0x00, 0x19, 0x19, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x12, 0x12, 0xE2, 0x00, 0x16, 0x16, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x13, 0x13, 0xE2, 0x00, 0x14, 0x14, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x15, 0x15, 0xE2, 0x00, 0x11, 0x11, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x16, 0x16, 0xE2, 0x00, 0x0F, 0x0F, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x18, 0x18, 0xE2, 0x00, 0x0D, 0x0D, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1A, 0x1A, 0xE2, 0x00, 0x0A, 0x0A, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1B, 0x1B, 0xE2, 0x00, 0x08, 0x08, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1D, 0x1D, 0xE2, 0x00, 0x05, 0x05, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1E, 0x1E, 0xE2, 0x00, 0x03, 0x03, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x20, 0x20, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1F, 0x1F, 0xE2, 0x00, 0xFD, 0xFD, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1F, 0x1F, 0xE2, 0x00, 0xFA, 0xFA, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1E, 0x1E, 0xE2, 0x00, 0xF7, 0xF7, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1D, 0x1D, 0xE2, 0x00, 0xF4, 0xF4, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1C, 0x1C, 0xE2, 0x00, 0xF1, 0xF1, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1C, 0x1C, 0xE2, 0x00, 0xEE, 0xEE, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1B, 0x1B, 0xE2, 0x00, 0xEB, 0xEB, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1A, 0x1A, 0xE2, 0x00, 0xE8, 0xE8, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1A, 0x1A, 0xE2, 0x00, 0xE5, 0xE5, 0x00, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x19, 0x19, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x48, 0x48, 0x00, 0xE2, 0x18, 0x18, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x40, 0x40, 0x00, 0xE2, 0x18, 0x18, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x38, 0x38, 0x00, 0xE2, 0x17, 0x17, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x30, 0x30, 0x00, 0xE2, 0x16, 0x16, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x28, 0x28, 0x00, 0xE2, 0x16, 0x16, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x20, 0x20, 0x00, 0xE2, 0x15, 0x15, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x18, 0x18, 0x00, 0xE2, 0x14, 0x14, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x10, 0x10, 0x00, 0xE2, 0x13, 0x13, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x08, 0x08, 0x00, 0xE2, 0x13, 0x13, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x12, 0x12, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x11, 0x11, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x11, 0x11, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x10, 0x10, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0F, 0x0F, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0E, 0x0E, 0xE2, 0x00, 0xE3, 0xE3, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0E, 0x0E, 0xE2, 0x00, 0xE5, 0xE5, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0D, 0x0D, 0xE2, 0x00, 0xE7, 0xE7, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0C, 0x0C, 0xE2, 0x00, 0xE8, 0xE8, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0C, 0x0C, 0xE2, 0x00, 0xEA, 0xEA, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0B, 0x0B, 0xE2, 0x00, 0xEB, 0xEB, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0A, 0x0A, 0xE2, 0x00, 0xED, 0xED, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0A, 0x0A, 0xE2, 0x00, 0xEE, 0xEE, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x09, 0x09, 0xE2, 0x00, 0xF0, 0xF0, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x08, 0x08, 0xE2, 0x00, 0xF1, 0xF1, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x08, 0x08, 0xE2, 0x00, 0xF3, 0xF3, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x07, 0x07, 0xE2, 0x00, 0xF4, 0xF4, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x07, 0x07, 0xE2, 0x00, 0xF6, 0xF6, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x06, 0x06, 0xE2, 0x00, 0xF7, 0xF7, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x05, 0x05, 0xE2, 0x00, 0xF8, 0xF8, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x05, 0x05, 0xE2, 0x00, 0xFA, 0xFA, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x04, 0x04, 0xE2, 0x00, 0xFB, 0xFB, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x03, 0x03, 0xE2, 0x00, 0xFD, 0xFD, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x03, 0x03, 0xE2, 0x00, 0xFE, 0xFE, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x02, 0x02, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x01, 0x01, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x01, 0x01, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x00, 0x00, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0xFF, 0xFF, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0xFE, 0xFE, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0xFD, 0xFD, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0xFD, 0xFD, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0xFC, 0xFC, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x0A, 0x00, 0x00, 0x0A, 0xE2, 0xFB, 0xFB, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x14, 0x00, 0x00, 0x14, 0xE2, 0xFB, 0xFB, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x1E, 0x00, 0x00, 0x1E, 0xE2, 0xFA, 0xFA, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x28, 0x00, 0x00, 0x28, 0xE2, 0xF9, 0xF9, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x32, 0x00, 0x00, 0x32, 0xE2, 0xF9, 0xF9, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x3C, 0x00, 0x00, 0x3C, 0xE2, 0xF8, 0xF8, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x46, 0x00, 0x00, 0x46, 0xE2, 0xF8, 0xF8, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0xE2, 0xF7, 0xF7, 0xE2, 0x00, 0x00, 0x00, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0xE4, 0xF6, 0xF6, 0xE4, 0x03, 0x00, 0x00, 0x03, 
	0x50, 0x00, 0x00, 0x50, 0xE5, 0xF6, 0xF6, 0xE5, 0x05, 0x00, 0x00, 0x05, 
	0x50, 0x00, 0x00, 0x50, 0xE7, 0xF5, 0xF5, 0xE7, 0x07, 0x00, 0x00, 0x07, 
	0x50, 0x00, 0x00, 0x50, 0xE8, 0xF4, 0xF4, 0xE8, 0x0A, 0x00, 0x00, 0x0A, 
	0x50, 0x00, 0x00, 0x50, 0xEA, 0xF4, 0xF4, 0xEA, 0x0C, 0x00, 0x00, 0x0C, 
	0x50, 0x00, 0x00, 0x50, 0xEB, 0xF3, 0xF3, 0xEB, 0x0F, 0x00, 0x00, 0x0F, 
	0x50, 0x00, 0x00, 0x50, 0xED, 0xF2, 0xF2, 0xED, 0x11, 0x00, 0x00, 0x11, 
	0x50, 0x00, 0x00, 0x50, 0xEE, 0xF1, 0xF1, 0xEE, 0x14, 0x00, 0x00, 0x14, 
	0x50, 0x00, 0x00, 0x50, 0xF0, 0xF1, 0xF1, 0xF0, 0x16, 0x00, 0x00, 0x16, 
	0x50, 0x00, 0x00, 0x50, 0xF1, 0xF0, 0xF0, 0xF1, 0x19, 0x00, 0x00, 0x19, 
	0x50, 0x00, 0x00, 0x50, 0xF3, 0xEF, 0xEF, 0xF3, 0x1B, 0x00, 0x00, 0x1B, 
	0x50, 0x00, 0x00, 0x50, 0xF5, 0xEF, 0xEF, 0xF5, 0x1E, 0x00, 0x00, 0x1E, 
	0x50, 0x00, 0x00, 0x50, 0xF6, 0xEE, 0xEE, 0xF6, 0x20, 0x00, 0x00, 0x20, 
	0x50, 0x00, 0x00, 0x50, 0xF8, 0xED, 0xED, 0xF8, 0x23, 0x00, 0x00, 0x23, 
	0x50, 0x00, 0x00, 0x50, 0xF9, 0xED, 0xED, 0xF9, 0x25, 0x00, 0x00, 0x25, 
	0x50, 0x00, 0x00, 0x50, 0xFB, 0xEC, 0xEC, 0xFB, 0x28, 0x00, 0x00, 0x28, 
	0x50, 0x00, 0x00, 0x50, 0xFC, 0xEB, 0xEB, 0xFC, 0x2A, 0x00, 0x00, 0x2A, 
	0x50, 0x00, 0x00, 0x50, 0xFE, 0xEA, 0xEA, 0xFE, 0x2D, 0x00, 0x00, 0x2D, 
	0x50, 0x00, 0x00, 0x50, 0xFF, 0xEA, 0xEA, 0xFF, 0x2F, 0x00, 0x00, 0x2F, 
	0x50, 0x00, 0x00, 0x50, 0x01, 0xE9, 0xE9, 0x01, 0x32, 0x00, 0x00, 0x32, 
	0x50, 0x00, 0x00, 0x50, 0x03, 0xE8, 0xE8, 0x03, 0x2F, 0x00, 0x00, 0x2F, 
	0x50, 0x00, 0x00, 0x50, 0x04, 0xE8, 0xE8, 0x04, 0x2D, 0x00, 0x00, 0x2D, 
	0x50, 0x00, 0x00, 0x50, 0x06, 0xE7, 0xE7, 0x06, 0x2A, 0x00, 0x00, 0x2A, 
	0x50, 0x00, 0x00, 0x50, 0x07, 0xE6, 0xE6, 0x07, 0x28, 0x00, 0x00, 0x28, 
	0x50, 0x00, 0x00, 0x50, 0x09, 0xE5, 0xE5, 0x09, 0x25, 0x00, 0x00, 0x25, 
	0x50, 0x00, 0x00, 0x50, 0x0A, 0xE5, 0xE5, 0x0A, 0x23, 0x00, 0x00, 0x23, 
	0x50, 0x00, 0x00, 0x50, 0x0C, 0xE4, 0xE4, 0x0C, 0x20, 0x00, 0x00, 0x20, 
	0x50, 0x00, 0x00, 0x50, 0x0D, 0xE3, 0xE3, 0x0D, 0x1E, 0x00, 0x00, 0x1E, 
	0x50, 0x00, 0x00, 0x50, 0x0E, 0xE3, 0xE3, 0x0E, 0x1C, 0x00, 0x00, 0x1C, 
	0x50, 0x00, 0x00, 0x50, 0x10, 0xE2, 0xE2, 0x10, 0x19, 0x00, 0x00, 0x19, 
	0x50, 0x00, 0x00, 0x50, 0x12, 0xE2, 0xE2, 0x12, 0x16, 0x00, 0x00, 0x16, 
	0x50, 0x00, 0x00, 0x50, 0x13, 0xE2, 0xE2, 0x13, 0x14, 0x00, 0x00, 0x14, 
	0x50, 0x00, 0x00, 0x50, 0x15, 0xE2, 0xE2, 0x15, 0x12, 0x00, 0x00, 0x12, 
	0x50, 0x00, 0x00, 0x50, 0x16, 0xE2, 0xE2, 0x16, 0x0F, 0x00, 0x00, 0x0F, 
	0x50, 0x00, 0x00, 0x50, 0x18, 0xE2, 0xE2, 0x18, 0x0D, 0x00, 0x00, 0x0D, 
	0x50, 0x00, 0x00, 0x50, 0x1A, 0xE2, 0xE2, 0x1A, 0x0A, 0x00, 0x00, 0x0A, 
	0x50, 0x00, 0x00, 0x50, 0x1B, 0xE2, 0xE2, 0x1B, 0x08, 0x00, 0x00, 0x08, 
	0x50, 0x00, 0x00, 0x50, 0x1D, 0xE2, 0xE2, 0x1D, 0x05, 0x00, 0x00, 0x05, 
	0x50, 0x00, 0x00, 0x50, 0x1E, 0xE2, 0xE2, 0x1E, 0x03, 0x00, 0x00, 0x03
};
extern const rom unsigned int OpenLoopGaitAddress = 
	FlashPointerAddress(OpenLoopGait);

const rom unsigned char CloseLoopGait[] = {
	0xC8, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x20, 0xE2, 0xE2, 0x20, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0xFE, 0x13, 0xFE, 0x13, 0x01, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1F, 0xE2, 0xE2, 0x1F, 0xFD, 0x00, 0x00, 0xFD, 0x06, 0x00, 0xF9, 0x13, 0xF9, 0x13, 0x06, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1F, 0xE2, 0xE2, 0x1F, 0xFA, 0x00, 0x00, 0xFA, 0x0D, 0x00, 0xF2, 0x13, 0xF2, 0x13, 0x0D, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1E, 0xE2, 0xE2, 0x1E, 0xF7, 0x00, 0x00, 0xF7, 0x17, 0x00, 0xE8, 0x13, 0xE8, 0x13, 0x17, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1D, 0xE2, 0xE2, 0x1D, 0xF4, 0x00, 0x00, 0xF4, 0x25, 0x00, 0xDA, 0x13, 0xDA, 0x13, 0x25, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1D, 0xE2, 0xE2, 0x1D, 0xF1, 0x00, 0x00, 0xF1, 0x35, 0x00, 0xCA, 0x13, 0xCA, 0x13, 0x35, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1C, 0xE2, 0xE2, 0x1C, 0xEE, 0x00, 0x00, 0xEE, 0x47, 0x00, 0xB8, 0x13, 0xB8, 0x13, 0x47, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1B, 0xE2, 0xE2, 0x1B, 0xEB, 0x00, 0x00, 0xEB, 0x5D, 0x00, 0xA2, 0x13, 0xA2, 0x13, 0x5D, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1A, 0xE2, 0xE2, 0x1A, 0xE8, 0x00, 0x00, 0xE8, 0x74, 0x00, 0x8B, 0x13, 0x8B, 0x13, 0x74, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1A, 0xE2, 0xE2, 0x1A, 0xE5, 0x00, 0x00, 0xE5, 0x8F, 0x00, 0x70, 0x13, 0x70, 0x13, 0x8F, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x19, 0xE2, 0xE2, 0x19, 0xE2, 0x00, 0x00, 0xE2, 0xAC, 0x00, 0x53, 0x13, 0x53, 0x13, 0xAC, 0x00, 
	0x48, 0x00, 0x00, 0x48, 0x18, 0xE2, 0xE2, 0x18, 0xE2, 0x00, 0x00, 0xE2, 0xCB, 0x00, 0x34, 0x13, 0x34, 0x13, 0xCB, 0x00, 
	0x40, 0x00, 0x00, 0x40, 0x18, 0xE2, 0xE2, 0x18, 0xE2, 0x00, 0x00, 0xE2, 0xED, 0x00, 0x12, 0x13, 0x12, 0x13, 0xED, 0x00, 
	0x38, 0x00, 0x00, 0x38, 0x17, 0xE2, 0xE2, 0x17, 0xE2, 0x00, 0x00, 0xE2, 0x10, 0x01, 0xEF, 0x12, 0xEF, 0x12, 0x10, 0x01, 
	0x30, 0x00, 0x00, 0x30, 0x16, 0xE2, 0xE2, 0x16, 0xE2, 0x00, 0x00, 0xE2, 0x37, 0x01, 0xC8, 0x12, 0xC8, 0x12, 0x37, 0x01, 
	0x28, 0x00, 0x00, 0x28, 0x16, 0xE2, 0xE2, 0x16, 0xE2, 0x00, 0x00, 0xE2, 0x5F, 0x01, 0xA0, 0x12, 0xA0, 0x12, 0x5F, 0x01, 
	0x20, 0x00, 0x00, 0x20, 0x15, 0xE2, 0xE2, 0x15, 0xE2, 0x00, 0x00, 0xE2, 0x89, 0x01, 0x76, 0x12, 0x76, 0x12, 0x89, 0x01, 
	0x18, 0x00, 0x00, 0x18, 0x14, 0xE2, 0xE2, 0x14, 0xE2, 0x00, 0x00, 0xE2, 0xB5, 0x01, 0x4A, 0x12, 0x4A, 0x12, 0xB5, 0x01, 
	0x10, 0x00, 0x00, 0x10, 0x13, 0xE2, 0xE2, 0x13, 0xE2, 0x00, 0x00, 0xE2, 0xE4, 0x01, 0x1B, 0x12, 0x1B, 0x12, 0xE4, 0x01, 
	0x08, 0x00, 0x00, 0x08, 0x13, 0xE2, 0xE2, 0x13, 0xE2, 0x00, 0x00, 0xE2, 0x14, 0x02, 0xEB, 0x11, 0xEB, 0x11, 0x14, 0x02, 
	0x00, 0x00, 0x00, 0x00, 0x12, 0xE2, 0xE2, 0x12, 0xE2, 0x00, 0x00, 0xE2, 0x46, 0x02, 0xB9, 0x11, 0xB9, 0x11, 0x46, 0x02, 
	0x00, 0x00, 0x00, 0x00, 0x11, 0xE2, 0xE2, 0x11, 0xE2, 0x00, 0x00, 0xE2, 0x7A, 0x02, 0x85, 0x11, 0x85, 0x11, 0x7A, 0x02, 
	0x00, 0x00, 0x00, 0x00, 0x11, 0xE2, 0xE2, 0x11, 0xE2, 0x00, 0x00, 0xE2, 0xAF, 0x02, 0x50, 0x11, 0x50, 0x11, 0xAF, 0x02, 
	0x00, 0x00, 0x00, 0x00, 0x10, 0xE2, 0xE2, 0x10, 0xE2, 0x00, 0x00, 0xE2, 0xE7, 0x02, 0x18, 0x11, 0x18, 0x11, 0xE7, 0x02, 
	0x00, 0x00, 0x00, 0x00, 0x0F, 0xE2, 0xE2, 0x0F, 0xE2, 0x00, 0x00, 0xE2, 0x20, 0x03, 0xE0, 0x10, 0xE0, 0x10, 0x20, 0x03, 
	0x00, 0x00, 0x00, 0x00, 0x0E, 0xE2, 0xE2, 0x0E, 0xE3, 0x00, 0x00, 0xE3, 0x5A, 0x03, 0xA5, 0x10, 0xA5, 0x10, 0x5A, 0x03, 
	0x00, 0x00, 0x00, 0x00, 0x0E, 0xE2, 0xE2, 0x0E, 0xE5, 0x00, 0x00, 0xE5, 0x96, 0x03, 0x69, 0x10, 0x69, 0x10, 0x96, 0x03, 
	0x00, 0x00, 0x00, 0x00, 0x0D, 0xE2, 0xE2, 0x0D, 0xE7, 0x00, 0x00, 0xE7, 0xD3, 0x03, 0x2C, 0x10, 0x2C, 0x10, 0xD3, 0x03, 
	0x00, 0x00, 0x00, 0x00, 0x0C, 0xE2, 0xE2, 0x0C, 0xE8, 0x00, 0x00, 0xE8, 0x12, 0x04, 0xED, 0x0F, 0xED, 0x0F, 0x12, 0x04, 
	0x00, 0x00, 0x00, 0x00, 0x0C, 0xE2, 0xE2, 0x0C, 0xE9, 0x00, 0x00, 0xE9, 0x51, 0x04, 0xAE, 0x0F, 0xAE, 0x0F, 0x51, 0x04, 
	0x00, 0x00, 0x00, 0x00, 0x0B, 0xE2, 0xE2, 0x0B, 0xEB, 0x00, 0x00, 0xEB, 0x93, 0x04, 0x6C, 0x0F, 0x6C, 0x0F, 0x93, 0x04, 
	0x00, 0x00, 0x00, 0x00, 0x0A, 0xE2, 0xE2, 0x0A, 0xEC, 0x00, 0x00, 0xEC, 0xD5, 0x04, 0x2A, 0x0F, 0x2A, 0x0F, 0xD5, 0x04, 
	0x00, 0x00, 0x00, 0x00, 0x0A, 0xE2, 0xE2, 0x0A, 0xEE, 0x00, 0x00, 0xEE, 0x18, 0x05, 0xE7, 0x0E, 0xE7, 0x0E, 0x18, 0x05, 
	0x00, 0x00, 0x00, 0x00, 0x09, 0xE2, 0xE2, 0x09, 0xF0, 0x00, 0x00, 0xF0, 0x5D, 0x05, 0xA2, 0x0E, 0xA2, 0x0E, 0x5D, 0x05, 
	0x00, 0x00, 0x00, 0x00, 0x08, 0xE2, 0xE2, 0x08, 0xF1, 0x00, 0x00, 0xF1, 0xA2, 0x05, 0x5D, 0x0E, 0x5D, 0x0E, 0xA2, 0x05, 
	0x00, 0x00, 0x00, 0x00, 0x08, 0xE2, 0xE2, 0x08, 0xF2, 0x00, 0x00, 0xF2, 0xE8, 0x05, 0x17, 0x0E, 0x17, 0x0E, 0xE8, 0x05, 
	0x00, 0x00, 0x00, 0x00, 0x07, 0xE2, 0xE2, 0x07, 0xF4, 0x00, 0x00, 0xF4, 0x30, 0x06, 0xCF, 0x0D, 0xCF, 0x0D, 0x30, 0x06, 
	0x00, 0x00, 0x00, 0x00, 0x07, 0xE2, 0xE2, 0x07, 0xF5, 0x00, 0x00, 0xF5, 0x78, 0x06, 0x87, 0x0D, 0x87, 0x0D, 0x78, 0x06, 
	0x00, 0x00, 0x00, 0x00, 0x06, 0xE2, 0xE2, 0x06, 0xF7, 0x00, 0x00, 0xF7, 0xC0, 0x06, 0x3F, 0x0D, 0x3F, 0x0D, 0xC0, 0x06, 
	0x00, 0x00, 0x00, 0x00, 0x05, 0xE2, 0xE2, 0x05, 0xF9, 0x00, 0x00, 0xF9, 0x0A, 0x07, 0xF5, 0x0C, 0xF5, 0x0C, 0x0A, 0x07, 
	0x00, 0x00, 0x00, 0x00, 0x05, 0xE2, 0xE2, 0x05, 0xFA, 0x00, 0x00, 0xFA, 0x54, 0x07, 0xAB, 0x0C, 0xAB, 0x0C, 0x54, 0x07, 
	0x00, 0x00, 0x00, 0x00, 0x04, 0xE2, 0xE2, 0x04, 0xFB, 0x00, 0x00, 0xFB, 0x9E, 0x07, 0x61, 0x0C, 0x61, 0x0C, 0x9E, 0x07, 
	0x00, 0x00, 0x00, 0x00, 0x03, 0xE2, 0xE2, 0x03, 0xFD, 0x00, 0x00, 0xFD, 0xE9, 0x07, 0x16, 0x0C, 0x16, 0x0C, 0xE9, 0x07, 
	0x00, 0x00, 0x00, 0x00, 0x03, 0xE2, 0xE2, 0x03, 0xFE, 0x00, 0x00, 0xFE, 0x35, 0x08, 0xCA, 0x0B, 0xCA, 0x0B, 0x35, 0x08, 
	0x00, 0x00, 0x00, 0x00, 0x02, 0xE2, 0xE2, 0x02, 0x00, 0x00, 0x00, 0x00, 0x81, 0x08, 0x7E, 0x0B, 0x7E, 0x0B, 0x81, 0x08, 
	0x00, 0x00, 0x00, 0x00, 0x01, 0xE2, 0xE2, 0x01, 0x00, 0x00, 0x00, 0x00, 0xCD, 0x08, 0x32, 0x0B, 0x32, 0x0B, 0xCD, 0x08, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0xE2, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x00, 0x19, 0x09, 0xE6, 0x0A, 0xE6, 0x0A, 0x19, 0x09, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0xE2, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x00, 0x66, 0x09, 0x99, 0x0A, 0x99, 0x0A, 0x66, 0x09, 
	0x00, 0x00, 0x00, 0x00, 0xFF, 0xE2, 0xE2, 0xFF, 0x00, 0x00, 0x00, 0x00, 0xB3, 0x09, 0x4C, 0x0A, 0x4C, 0x0A, 0xB3, 0x09, 
	0x00, 0x00, 0x00, 0x00, 0xFE, 0xE2, 0xE2, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0A, 0x00, 0x0A, 0x00, 0x0A, 0x00, 0x0A, 
	0x00, 0x00, 0x00, 0x00, 0xFE, 0xE2, 0xE2, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x4C, 0x0A, 0xB3, 0x09, 0xB3, 0x09, 0x4C, 0x0A, 
	0x00, 0x00, 0x00, 0x00, 0xFD, 0xE2, 0xE2, 0xFD, 0x00, 0x00, 0x00, 0x00, 0x99, 0x0A, 0x66, 0x09, 0x66, 0x09, 0x99, 0x0A, 
	0x00, 0x00, 0x00, 0x00, 0xFC, 0xE2, 0xE2, 0xFC, 0x00, 0x00, 0x00, 0x00, 0xE6, 0x0A, 0x19, 0x09, 0x19, 0x09, 0xE6, 0x0A, 
	0x00, 0x0A, 0x0A, 0x00, 0xFB, 0xE2, 0xE2, 0xFB, 0x00, 0x00, 0x00, 0x00, 0x32, 0x0B, 0xCD, 0x08, 0xCD, 0x08, 0x32, 0x0B, 
	0x00, 0x14, 0x14, 0x00, 0xFB, 0xE2, 0xE2, 0xFB, 0x00, 0x00, 0x00, 0x00, 0x7E, 0x0B, 0x81, 0x08, 0x81, 0x08, 0x7E, 0x0B, 
	0x00, 0x1E, 0x1E, 0x00, 0xFA, 0xE2, 0xE2, 0xFA, 0x00, 0x00, 0x00, 0x00, 0xCA, 0x0B, 0x35, 0x08, 0x35, 0x08, 0xCA, 0x0B, 
	0x00, 0x28, 0x28, 0x00, 0xF9, 0xE2, 0xE2, 0xF9, 0x00, 0x00, 0x00, 0x00, 0x16, 0x0C, 0xE9, 0x07, 0xE9, 0x07, 0x16, 0x0C, 
	0x00, 0x32, 0x32, 0x00, 0xF9, 0xE2, 0xE2, 0xF9, 0x00, 0x00, 0x00, 0x00, 0x61, 0x0C, 0x9E, 0x07, 0x9E, 0x07, 0x61, 0x0C, 
	0x00, 0x3C, 0x3C, 0x00, 0xF8, 0xE2, 0xE2, 0xF8, 0x00, 0x00, 0x00, 0x00, 0xAB, 0x0C, 0x54, 0x07, 0x54, 0x07, 0xAB, 0x0C, 
	0x00, 0x46, 0x46, 0x00, 0xF8, 0xE2, 0xE2, 0xF8, 0x00, 0x00, 0x00, 0x00, 0xF5, 0x0C, 0x0A, 0x07, 0x0A, 0x07, 0xF5, 0x0C, 
	0x00, 0x50, 0x50, 0x00, 0xF7, 0xE2, 0xE2, 0xF7, 0x00, 0x00, 0x00, 0x00, 0x3F, 0x0D, 0xC0, 0x06, 0xC0, 0x06, 0x3F, 0x0D, 
	0x00, 0x50, 0x50, 0x00, 0xF6, 0xE4, 0xE4, 0xF6, 0x00, 0x02, 0x02, 0x00, 0x87, 0x0D, 0x78, 0x06, 0x78, 0x06, 0x87, 0x0D, 
	0x00, 0x50, 0x50, 0x00, 0xF6, 0xE5, 0xE5, 0xF6, 0x00, 0x05, 0x05, 0x00, 0xCF, 0x0D, 0x30, 0x06, 0x30, 0x06, 0xCF, 0x0D, 
	0x00, 0x50, 0x50, 0x00, 0xF5, 0xE7, 0xE7, 0xF5, 0x00, 0x07, 0x07, 0x00, 0x17, 0x0E, 0xE8, 0x05, 0xE8, 0x05, 0x17, 0x0E, 
	0x00, 0x50, 0x50, 0x00, 0xF4, 0xE8, 0xE8, 0xF4, 0x00, 0x0A, 0x0A, 0x00, 0x5D, 0x0E, 0xA2, 0x05, 0xA2, 0x05, 0x5D, 0x0E, 
	0x00, 0x50, 0x50, 0x00, 0xF3, 0xEA, 0xEA, 0xF3, 0x00, 0x0C, 0x0C, 0x00, 0xA2, 0x0E, 0x5D, 0x05, 0x5D, 0x05, 0xA2, 0x0E, 
	0x00, 0x50, 0x50, 0x00, 0xF3, 0xEB, 0xEB, 0xF3, 0x00, 0x0F, 0x0F, 0x00, 0xE7, 0x0E, 0x18, 0x05, 0x18, 0x05, 0xE7, 0x0E, 
	0x00, 0x50, 0x50, 0x00, 0xF2, 0xED, 0xED, 0xF2, 0x00, 0x12, 0x12, 0x00, 0x2A, 0x0F, 0xD5, 0x04, 0xD5, 0x04, 0x2A, 0x0F, 
	0x00, 0x50, 0x50, 0x00, 0xF1, 0xEE, 0xEE, 0xF1, 0x00, 0x14, 0x14, 0x00, 0x6C, 0x0F, 0x93, 0x04, 0x93, 0x04, 0x6C, 0x0F, 
	0x00, 0x50, 0x50, 0x00, 0xF1, 0xF0, 0xF0, 0xF1, 0x00, 0x16, 0x16, 0x00, 0xAE, 0x0F, 0x51, 0x04, 0x51, 0x04, 0xAE, 0x0F, 
	0x00, 0x50, 0x50, 0x00, 0xF0, 0xF2, 0xF2, 0xF0, 0x00, 0x19, 0x19, 0x00, 0xED, 0x0F, 0x12, 0x04, 0x12, 0x04, 0xED, 0x0F, 
	0x00, 0x50, 0x50, 0x00, 0xEF, 0xF3, 0xF3, 0xEF, 0x00, 0x1C, 0x1C, 0x00, 0x2C, 0x10, 0xD3, 0x03, 0xD3, 0x03, 0x2C, 0x10, 
	0x00, 0x50, 0x50, 0x00, 0xEF, 0xF5, 0xF5, 0xEF, 0x00, 0x1E, 0x1E, 0x00, 0x69, 0x10, 0x96, 0x03, 0x96, 0x03, 0x69, 0x10, 
	0x00, 0x50, 0x50, 0x00, 0xEE, 0xF6, 0xF6, 0xEE, 0x00, 0x21, 0x21, 0x00, 0xA5, 0x10, 0x5A, 0x03, 0x5A, 0x03, 0xA5, 0x10, 
	0x00, 0x50, 0x50, 0x00, 0xED, 0xF8, 0xF8, 0xED, 0x00, 0x23, 0x23, 0x00, 0xE0, 0x10, 0x20, 0x03, 0x20, 0x03, 0xE0, 0x10, 
	0x00, 0x50, 0x50, 0x00, 0xEC, 0xF9, 0xF9, 0xEC, 0x00, 0x26, 0x26, 0x00, 0x18, 0x11, 0xE7, 0x02, 0xE7, 0x02, 0x18, 0x11, 
	0x00, 0x50, 0x50, 0x00, 0xEC, 0xFB, 0xFB, 0xEC, 0x00, 0x28, 0x28, 0x00, 0x50, 0x11, 0xAF, 0x02, 0xAF, 0x02, 0x50, 0x11, 
	0x00, 0x50, 0x50, 0x00, 0xEB, 0xFC, 0xFC, 0xEB, 0x00, 0x2B, 0x2B, 0x00, 0x85, 0x11, 0x7A, 0x02, 0x7A, 0x02, 0x85, 0x11, 
	0x00, 0x50, 0x50, 0x00, 0xEA, 0xFE, 0xFE, 0xEA, 0x00, 0x2D, 0x2D, 0x00, 0xB9, 0x11, 0x46, 0x02, 0x46, 0x02, 0xB9, 0x11, 
	0x00, 0x50, 0x50, 0x00, 0xEA, 0xFF, 0xFF, 0xEA, 0x00, 0x30, 0x30, 0x00, 0xEB, 0x11, 0x14, 0x02, 0x14, 0x02, 0xEB, 0x11, 
	0x00, 0x50, 0x50, 0x00, 0xE9, 0x01, 0x01, 0xE9, 0x00, 0x32, 0x32, 0x00, 0x1B, 0x12, 0xE4, 0x01, 0xE4, 0x01, 0x1B, 0x12, 
	0x00, 0x50, 0x50, 0x00, 0xE8, 0x03, 0x03, 0xE8, 0x00, 0x2F, 0x2F, 0x00, 0x4A, 0x12, 0xB5, 0x01, 0xB5, 0x01, 0x4A, 0x12, 
	0x00, 0x50, 0x50, 0x00, 0xE8, 0x04, 0x04, 0xE8, 0x00, 0x2D, 0x2D, 0x00, 0x76, 0x12, 0x89, 0x01, 0x89, 0x01, 0x76, 0x12, 
	0x00, 0x50, 0x50, 0x00, 0xE7, 0x06, 0x06, 0xE7, 0x00, 0x2A, 0x2A, 0x00, 0xA0, 0x12, 0x5F, 0x01, 0x5F, 0x01, 0xA0, 0x12, 
	0x00, 0x50, 0x50, 0x00, 0xE6, 0x07, 0x07, 0xE6, 0x00, 0x28, 0x28, 0x00, 0xC8, 0x12, 0x37, 0x01, 0x37, 0x01, 0xC8, 0x12, 
	0x00, 0x50, 0x50, 0x00, 0xE5, 0x09, 0x09, 0xE5, 0x00, 0x25, 0x25, 0x00, 0xEF, 0x12, 0x10, 0x01, 0x10, 0x01, 0xEF, 0x12, 
	0x00, 0x50, 0x50, 0x00, 0xE5, 0x0A, 0x0A, 0xE5, 0x00, 0x23, 0x23, 0x00, 0x12, 0x13, 0xED, 0x00, 0xED, 0x00, 0x12, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE4, 0x0C, 0x0C, 0xE4, 0x00, 0x20, 0x20, 0x00, 0x34, 0x13, 0xCB, 0x00, 0xCB, 0x00, 0x34, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE3, 0x0D, 0x0D, 0xE3, 0x00, 0x1E, 0x1E, 0x00, 0x53, 0x13, 0xAC, 0x00, 0xAC, 0x00, 0x53, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE3, 0x0F, 0x0F, 0xE3, 0x00, 0x1B, 0x1B, 0x00, 0x70, 0x13, 0x8F, 0x00, 0x8F, 0x00, 0x70, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x10, 0x10, 0xE2, 0x00, 0x19, 0x19, 0x00, 0x8B, 0x13, 0x74, 0x00, 0x74, 0x00, 0x8B, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x12, 0x12, 0xE2, 0x00, 0x16, 0x16, 0x00, 0xA2, 0x13, 0x5D, 0x00, 0x5D, 0x00, 0xA2, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x13, 0x13, 0xE2, 0x00, 0x14, 0x14, 0x00, 0xB8, 0x13, 0x47, 0x00, 0x47, 0x00, 0xB8, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x15, 0x15, 0xE2, 0x00, 0x11, 0x11, 0x00, 0xCA, 0x13, 0x35, 0x00, 0x35, 0x00, 0xCA, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x16, 0x16, 0xE2, 0x00, 0x0F, 0x0F, 0x00, 0xDA, 0x13, 0x25, 0x00, 0x25, 0x00, 0xDA, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x18, 0x18, 0xE2, 0x00, 0x0D, 0x0D, 0x00, 0xE8, 0x13, 0x17, 0x00, 0x17, 0x00, 0xE8, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1A, 0x1A, 0xE2, 0x00, 0x0A, 0x0A, 0x00, 0xF2, 0x13, 0x0D, 0x00, 0x0D, 0x00, 0xF2, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1B, 0x1B, 0xE2, 0x00, 0x08, 0x08, 0x00, 0xF9, 0x13, 0x06, 0x00, 0x06, 0x00, 0xF9, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1D, 0x1D, 0xE2, 0x00, 0x05, 0x05, 0x00, 0xFE, 0x13, 0x01, 0x00, 0x01, 0x00, 0xFE, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1E, 0x1E, 0xE2, 0x00, 0x03, 0x03, 0x00, 0x00, 0x14, 0x00, 0x00, 0x00, 0x00, 0x00, 0x14, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x20, 0x20, 0xE2, 0x00, 0x00, 0x00, 0x00, 0xFE, 0x13, 0x01, 0x00, 0x01, 0x00, 0xFE, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1F, 0x1F, 0xE2, 0x00, 0xFD, 0xFD, 0x00, 0xF9, 0x13, 0x06, 0x00, 0x06, 0x00, 0xF9, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1F, 0x1F, 0xE2, 0x00, 0xFA, 0xFA, 0x00, 0xF2, 0x13, 0x0D, 0x00, 0x0D, 0x00, 0xF2, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1E, 0x1E, 0xE2, 0x00, 0xF7, 0xF7, 0x00, 0xE8, 0x13, 0x17, 0x00, 0x17, 0x00, 0xE8, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1D, 0x1D, 0xE2, 0x00, 0xF4, 0xF4, 0x00, 0xDA, 0x13, 0x25, 0x00, 0x25, 0x00, 0xDA, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1C, 0x1C, 0xE2, 0x00, 0xF1, 0xF1, 0x00, 0xCA, 0x13, 0x35, 0x00, 0x35, 0x00, 0xCA, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1C, 0x1C, 0xE2, 0x00, 0xEE, 0xEE, 0x00, 0xB8, 0x13, 0x47, 0x00, 0x47, 0x00, 0xB8, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1B, 0x1B, 0xE2, 0x00, 0xEB, 0xEB, 0x00, 0xA2, 0x13, 0x5D, 0x00, 0x5D, 0x00, 0xA2, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1A, 0x1A, 0xE2, 0x00, 0xE8, 0xE8, 0x00, 0x8B, 0x13, 0x74, 0x00, 0x74, 0x00, 0x8B, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x1A, 0x1A, 0xE2, 0x00, 0xE5, 0xE5, 0x00, 0x70, 0x13, 0x8F, 0x00, 0x8F, 0x00, 0x70, 0x13, 
	0x00, 0x50, 0x50, 0x00, 0xE2, 0x19, 0x19, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0x53, 0x13, 0xAC, 0x00, 0xAC, 0x00, 0x53, 0x13, 
	0x00, 0x48, 0x48, 0x00, 0xE2, 0x18, 0x18, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0x34, 0x13, 0xCB, 0x00, 0xCB, 0x00, 0x34, 0x13, 
	0x00, 0x40, 0x40, 0x00, 0xE2, 0x18, 0x18, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0x12, 0x13, 0xED, 0x00, 0xED, 0x00, 0x12, 0x13, 
	0x00, 0x38, 0x38, 0x00, 0xE2, 0x17, 0x17, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0xEF, 0x12, 0x10, 0x01, 0x10, 0x01, 0xEF, 0x12, 
	0x00, 0x30, 0x30, 0x00, 0xE2, 0x16, 0x16, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0xC8, 0x12, 0x37, 0x01, 0x37, 0x01, 0xC8, 0x12, 
	0x00, 0x28, 0x28, 0x00, 0xE2, 0x16, 0x16, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0xA0, 0x12, 0x5F, 0x01, 0x5F, 0x01, 0xA0, 0x12, 
	0x00, 0x20, 0x20, 0x00, 0xE2, 0x15, 0x15, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0x76, 0x12, 0x89, 0x01, 0x89, 0x01, 0x76, 0x12, 
	0x00, 0x18, 0x18, 0x00, 0xE2, 0x14, 0x14, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0x4A, 0x12, 0xB5, 0x01, 0xB5, 0x01, 0x4A, 0x12, 
	0x00, 0x10, 0x10, 0x00, 0xE2, 0x13, 0x13, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0x1B, 0x12, 0xE4, 0x01, 0xE4, 0x01, 0x1B, 0x12, 
	0x00, 0x08, 0x08, 0x00, 0xE2, 0x13, 0x13, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0xEB, 0x11, 0x14, 0x02, 0x14, 0x02, 0xEB, 0x11, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x12, 0x12, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0xB9, 0x11, 0x46, 0x02, 0x46, 0x02, 0xB9, 0x11, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x11, 0x11, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0x85, 0x11, 0x7A, 0x02, 0x7A, 0x02, 0x85, 0x11, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x11, 0x11, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0x50, 0x11, 0xAF, 0x02, 0xAF, 0x02, 0x50, 0x11, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x10, 0x10, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0x18, 0x11, 0xE7, 0x02, 0xE7, 0x02, 0x18, 0x11, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0F, 0x0F, 0xE2, 0x00, 0xE2, 0xE2, 0x00, 0xE0, 0x10, 0x20, 0x03, 0x20, 0x03, 0xE0, 0x10, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0E, 0x0E, 0xE2, 0x00, 0xE3, 0xE3, 0x00, 0xA5, 0x10, 0x5A, 0x03, 0x5A, 0x03, 0xA5, 0x10, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0E, 0x0E, 0xE2, 0x00, 0xE5, 0xE5, 0x00, 0x69, 0x10, 0x96, 0x03, 0x96, 0x03, 0x69, 0x10, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0D, 0x0D, 0xE2, 0x00, 0xE7, 0xE7, 0x00, 0x2C, 0x10, 0xD3, 0x03, 0xD3, 0x03, 0x2C, 0x10, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0C, 0x0C, 0xE2, 0x00, 0xE8, 0xE8, 0x00, 0xED, 0x0F, 0x12, 0x04, 0x12, 0x04, 0xED, 0x0F, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0C, 0x0C, 0xE2, 0x00, 0xEA, 0xEA, 0x00, 0xAE, 0x0F, 0x51, 0x04, 0x51, 0x04, 0xAE, 0x0F, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0B, 0x0B, 0xE2, 0x00, 0xEB, 0xEB, 0x00, 0x6C, 0x0F, 0x93, 0x04, 0x93, 0x04, 0x6C, 0x0F, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0A, 0x0A, 0xE2, 0x00, 0xED, 0xED, 0x00, 0x2A, 0x0F, 0xD5, 0x04, 0xD5, 0x04, 0x2A, 0x0F, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x0A, 0x0A, 0xE2, 0x00, 0xEE, 0xEE, 0x00, 0xE7, 0x0E, 0x18, 0x05, 0x18, 0x05, 0xE7, 0x0E, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x09, 0x09, 0xE2, 0x00, 0xF0, 0xF0, 0x00, 0xA2, 0x0E, 0x5D, 0x05, 0x5D, 0x05, 0xA2, 0x0E, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x08, 0x08, 0xE2, 0x00, 0xF1, 0xF1, 0x00, 0x5D, 0x0E, 0xA2, 0x05, 0xA2, 0x05, 0x5D, 0x0E, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x08, 0x08, 0xE2, 0x00, 0xF3, 0xF3, 0x00, 0x17, 0x0E, 0xE8, 0x05, 0xE8, 0x05, 0x17, 0x0E, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x07, 0x07, 0xE2, 0x00, 0xF4, 0xF4, 0x00, 0xCF, 0x0D, 0x30, 0x06, 0x30, 0x06, 0xCF, 0x0D, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x07, 0x07, 0xE2, 0x00, 0xF6, 0xF6, 0x00, 0x87, 0x0D, 0x78, 0x06, 0x78, 0x06, 0x87, 0x0D, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x06, 0x06, 0xE2, 0x00, 0xF7, 0xF7, 0x00, 0x3F, 0x0D, 0xC0, 0x06, 0xC0, 0x06, 0x3F, 0x0D, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x05, 0x05, 0xE2, 0x00, 0xF8, 0xF8, 0x00, 0xF5, 0x0C, 0x0A, 0x07, 0x0A, 0x07, 0xF5, 0x0C, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x05, 0x05, 0xE2, 0x00, 0xFA, 0xFA, 0x00, 0xAB, 0x0C, 0x54, 0x07, 0x54, 0x07, 0xAB, 0x0C, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x04, 0x04, 0xE2, 0x00, 0xFB, 0xFB, 0x00, 0x61, 0x0C, 0x9E, 0x07, 0x9E, 0x07, 0x61, 0x0C, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x03, 0x03, 0xE2, 0x00, 0xFD, 0xFD, 0x00, 0x16, 0x0C, 0xE9, 0x07, 0xE9, 0x07, 0x16, 0x0C, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x03, 0x03, 0xE2, 0x00, 0xFE, 0xFE, 0x00, 0xCA, 0x0B, 0x35, 0x08, 0x35, 0x08, 0xCA, 0x0B, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x02, 0x02, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x7E, 0x0B, 0x81, 0x08, 0x81, 0x08, 0x7E, 0x0B, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x01, 0x01, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x32, 0x0B, 0xCD, 0x08, 0xCD, 0x08, 0x32, 0x0B, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x01, 0x01, 0xE2, 0x00, 0x00, 0x00, 0x00, 0xE6, 0x0A, 0x19, 0x09, 0x19, 0x09, 0xE6, 0x0A, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0x00, 0x00, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x99, 0x0A, 0x66, 0x09, 0x66, 0x09, 0x99, 0x0A, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0xFF, 0xFF, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x4C, 0x0A, 0xB3, 0x09, 0xB3, 0x09, 0x4C, 0x0A, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0xFE, 0xFE, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0A, 0x00, 0x0A, 0x00, 0x0A, 0x00, 0x0A, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0xFD, 0xFD, 0xE2, 0x00, 0x00, 0x00, 0x00, 0xB3, 0x09, 0x4C, 0x0A, 0x4C, 0x0A, 0xB3, 0x09, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0xFD, 0xFD, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x66, 0x09, 0x99, 0x0A, 0x99, 0x0A, 0x66, 0x09, 
	0x00, 0x00, 0x00, 0x00, 0xE2, 0xFC, 0xFC, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x19, 0x09, 0xE6, 0x0A, 0xE6, 0x0A, 0x19, 0x09, 
	0x0A, 0x00, 0x00, 0x0A, 0xE2, 0xFB, 0xFB, 0xE2, 0x00, 0x00, 0x00, 0x00, 0xCD, 0x08, 0x32, 0x0B, 0x32, 0x0B, 0xCD, 0x08, 
	0x14, 0x00, 0x00, 0x14, 0xE2, 0xFB, 0xFB, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x81, 0x08, 0x7E, 0x0B, 0x7E, 0x0B, 0x81, 0x08, 
	0x1E, 0x00, 0x00, 0x1E, 0xE2, 0xFA, 0xFA, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x35, 0x08, 0xCA, 0x0B, 0xCA, 0x0B, 0x35, 0x08, 
	0x28, 0x00, 0x00, 0x28, 0xE2, 0xF9, 0xF9, 0xE2, 0x00, 0x00, 0x00, 0x00, 0xE9, 0x07, 0x16, 0x0C, 0x16, 0x0C, 0xE9, 0x07, 
	0x32, 0x00, 0x00, 0x32, 0xE2, 0xF9, 0xF9, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x9E, 0x07, 0x61, 0x0C, 0x61, 0x0C, 0x9E, 0x07, 
	0x3C, 0x00, 0x00, 0x3C, 0xE2, 0xF8, 0xF8, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x54, 0x07, 0xAB, 0x0C, 0xAB, 0x0C, 0x54, 0x07, 
	0x46, 0x00, 0x00, 0x46, 0xE2, 0xF8, 0xF8, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x0A, 0x07, 0xF5, 0x0C, 0xF5, 0x0C, 0x0A, 0x07, 
	0x50, 0x00, 0x00, 0x50, 0xE2, 0xF7, 0xF7, 0xE2, 0x00, 0x00, 0x00, 0x00, 0xC0, 0x06, 0x3F, 0x0D, 0x3F, 0x0D, 0xC0, 0x06, 
	0x50, 0x00, 0x00, 0x50, 0xE4, 0xF6, 0xF6, 0xE4, 0x03, 0x00, 0x00, 0x03, 0x78, 0x06, 0x87, 0x0D, 0x87, 0x0D, 0x78, 0x06, 
	0x50, 0x00, 0x00, 0x50, 0xE5, 0xF6, 0xF6, 0xE5, 0x05, 0x00, 0x00, 0x05, 0x30, 0x06, 0xCF, 0x0D, 0xCF, 0x0D, 0x30, 0x06, 
	0x50, 0x00, 0x00, 0x50, 0xE7, 0xF5, 0xF5, 0xE7, 0x07, 0x00, 0x00, 0x07, 0xE8, 0x05, 0x17, 0x0E, 0x17, 0x0E, 0xE8, 0x05, 
	0x50, 0x00, 0x00, 0x50, 0xE8, 0xF4, 0xF4, 0xE8, 0x0A, 0x00, 0x00, 0x0A, 0xA2, 0x05, 0x5D, 0x0E, 0x5D, 0x0E, 0xA2, 0x05, 
	0x50, 0x00, 0x00, 0x50, 0xEA, 0xF4, 0xF4, 0xEA, 0x0C, 0x00, 0x00, 0x0C, 0x5D, 0x05, 0xA2, 0x0E, 0xA2, 0x0E, 0x5D, 0x05, 
	0x50, 0x00, 0x00, 0x50, 0xEB, 0xF3, 0xF3, 0xEB, 0x0F, 0x00, 0x00, 0x0F, 0x18, 0x05, 0xE7, 0x0E, 0xE7, 0x0E, 0x18, 0x05, 
	0x50, 0x00, 0x00, 0x50, 0xED, 0xF2, 0xF2, 0xED, 0x11, 0x00, 0x00, 0x11, 0xD5, 0x04, 0x2A, 0x0F, 0x2A, 0x0F, 0xD5, 0x04, 
	0x50, 0x00, 0x00, 0x50, 0xEE, 0xF1, 0xF1, 0xEE, 0x14, 0x00, 0x00, 0x14, 0x93, 0x04, 0x6C, 0x0F, 0x6C, 0x0F, 0x93, 0x04, 
	0x50, 0x00, 0x00, 0x50, 0xF0, 0xF1, 0xF1, 0xF0, 0x16, 0x00, 0x00, 0x16, 0x51, 0x04, 0xAE, 0x0F, 0xAE, 0x0F, 0x51, 0x04, 
	0x50, 0x00, 0x00, 0x50, 0xF1, 0xF0, 0xF0, 0xF1, 0x19, 0x00, 0x00, 0x19, 0x12, 0x04, 0xED, 0x0F, 0xED, 0x0F, 0x12, 0x04, 
	0x50, 0x00, 0x00, 0x50, 0xF3, 0xEF, 0xEF, 0xF3, 0x1B, 0x00, 0x00, 0x1B, 0xD3, 0x03, 0x2C, 0x10, 0x2C, 0x10, 0xD3, 0x03, 
	0x50, 0x00, 0x00, 0x50, 0xF5, 0xEF, 0xEF, 0xF5, 0x1E, 0x00, 0x00, 0x1E, 0x96, 0x03, 0x69, 0x10, 0x69, 0x10, 0x96, 0x03, 
	0x50, 0x00, 0x00, 0x50, 0xF6, 0xEE, 0xEE, 0xF6, 0x20, 0x00, 0x00, 0x20, 0x5A, 0x03, 0xA5, 0x10, 0xA5, 0x10, 0x5A, 0x03, 
	0x50, 0x00, 0x00, 0x50, 0xF8, 0xED, 0xED, 0xF8, 0x23, 0x00, 0x00, 0x23, 0x20, 0x03, 0xE0, 0x10, 0xE0, 0x10, 0x20, 0x03, 
	0x50, 0x00, 0x00, 0x50, 0xF9, 0xED, 0xED, 0xF9, 0x25, 0x00, 0x00, 0x25, 0xE7, 0x02, 0x18, 0x11, 0x18, 0x11, 0xE7, 0x02, 
	0x50, 0x00, 0x00, 0x50, 0xFB, 0xEC, 0xEC, 0xFB, 0x28, 0x00, 0x00, 0x28, 0xAF, 0x02, 0x50, 0x11, 0x50, 0x11, 0xAF, 0x02, 
	0x50, 0x00, 0x00, 0x50, 0xFC, 0xEB, 0xEB, 0xFC, 0x2A, 0x00, 0x00, 0x2A, 0x7A, 0x02, 0x85, 0x11, 0x85, 0x11, 0x7A, 0x02, 
	0x50, 0x00, 0x00, 0x50, 0xFE, 0xEA, 0xEA, 0xFE, 0x2D, 0x00, 0x00, 0x2D, 0x46, 0x02, 0xB9, 0x11, 0xB9, 0x11, 0x46, 0x02, 
	0x50, 0x00, 0x00, 0x50, 0xFF, 0xEA, 0xEA, 0xFF, 0x2F, 0x00, 0x00, 0x2F, 0x14, 0x02, 0xEB, 0x11, 0xEB, 0x11, 0x14, 0x02, 
	0x50, 0x00, 0x00, 0x50, 0x01, 0xE9, 0xE9, 0x01, 0x32, 0x00, 0x00, 0x32, 0xE4, 0x01, 0x1B, 0x12, 0x1B, 0x12, 0xE4, 0x01, 
	0x50, 0x00, 0x00, 0x50, 0x03, 0xE8, 0xE8, 0x03, 0x2F, 0x00, 0x00, 0x2F, 0xB5, 0x01, 0x4A, 0x12, 0x4A, 0x12, 0xB5, 0x01, 
	0x50, 0x00, 0x00, 0x50, 0x04, 0xE8, 0xE8, 0x04, 0x2D, 0x00, 0x00, 0x2D, 0x89, 0x01, 0x76, 0x12, 0x76, 0x12, 0x89, 0x01, 
	0x50, 0x00, 0x00, 0x50, 0x06, 0xE7, 0xE7, 0x06, 0x2A, 0x00, 0x00, 0x2A, 0x5F, 0x01, 0xA0, 0x12, 0xA0, 0x12, 0x5F, 0x01, 
	0x50, 0x00, 0x00, 0x50, 0x07, 0xE6, 0xE6, 0x07, 0x28, 0x00, 0x00, 0x28, 0x37, 0x01, 0xC8, 0x12, 0xC8, 0x12, 0x37, 0x01, 
	0x50, 0x00, 0x00, 0x50, 0x09, 0xE5, 0xE5, 0x09, 0x25, 0x00, 0x00, 0x25, 0x10, 0x01, 0xEF, 0x12, 0xEF, 0x12, 0x10, 0x01, 
	0x50, 0x00, 0x00, 0x50, 0x0A, 0xE5, 0xE5, 0x0A, 0x23, 0x00, 0x00, 0x23, 0xED, 0x00, 0x12, 0x13, 0x12, 0x13, 0xED, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x0C, 0xE4, 0xE4, 0x0C, 0x20, 0x00, 0x00, 0x20, 0xCB, 0x00, 0x34, 0x13, 0x34, 0x13, 0xCB, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x0D, 0xE3, 0xE3, 0x0D, 0x1E, 0x00, 0x00, 0x1E, 0xAC, 0x00, 0x53, 0x13, 0x53, 0x13, 0xAC, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x0E, 0xE3, 0xE3, 0x0E, 0x1C, 0x00, 0x00, 0x1C, 0x8F, 0x00, 0x70, 0x13, 0x70, 0x13, 0x8F, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x10, 0xE2, 0xE2, 0x10, 0x19, 0x00, 0x00, 0x19, 0x74, 0x00, 0x8B, 0x13, 0x8B, 0x13, 0x74, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x12, 0xE2, 0xE2, 0x12, 0x16, 0x00, 0x00, 0x16, 0x5D, 0x00, 0xA2, 0x13, 0xA2, 0x13, 0x5D, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x13, 0xE2, 0xE2, 0x13, 0x14, 0x00, 0x00, 0x14, 0x47, 0x00, 0xB8, 0x13, 0xB8, 0x13, 0x47, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x15, 0xE2, 0xE2, 0x15, 0x12, 0x00, 0x00, 0x12, 0x35, 0x00, 0xCA, 0x13, 0xCA, 0x13, 0x35, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x16, 0xE2, 0xE2, 0x16, 0x0F, 0x00, 0x00, 0x0F, 0x25, 0x00, 0xDA, 0x13, 0xDA, 0x13, 0x25, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x18, 0xE2, 0xE2, 0x18, 0x0D, 0x00, 0x00, 0x0D, 0x17, 0x00, 0xE8, 0x13, 0xE8, 0x13, 0x17, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1A, 0xE2, 0xE2, 0x1A, 0x0A, 0x00, 0x00, 0x0A, 0x0D, 0x00, 0xF2, 0x13, 0xF2, 0x13, 0x0D, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1B, 0xE2, 0xE2, 0x1B, 0x08, 0x00, 0x00, 0x08, 0x06, 0x00, 0xF9, 0x13, 0xF9, 0x13, 0x06, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1D, 0xE2, 0xE2, 0x1D, 0x05, 0x00, 0x00, 0x05, 0x01, 0x00, 0xFE, 0x13, 0xFE, 0x13, 0x01, 0x00, 
	0x50, 0x00, 0x00, 0x50, 0x1E, 0xE2, 0xE2, 0x1E, 0x03, 0x00, 0x00, 0x03,	0x00, 0x00, 0x00, 0x14, 0x00, 0x14, 0x00, 0x00
};
extern const rom unsigned int CloseLoopGaitAddress = 
	FlashPointerAddress(CloseLoopGait);
*/
	
const rom unsigned char EndByte = 0xFF;
extern const rom unsigned int SizeOfFlashFile = FlashVariableAddress(EndByte);

#pragma code
